<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://ticketing.getyourguide.com
 * @since      1.0.0
 *
 * @package    Getyourguide_Ticketing
 * @subpackage Getyourguide_Ticketing/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Getyourguide_Ticketing
 * @subpackage Getyourguide_Ticketing/admin
 * @author     Marcello Romanelli <marcello.romanelli@getyourguide.com>
 */
class Getyourguide_Ticketing_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Getyourguide_Ticketing_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Getyourguide_Ticketing_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/getyourguide-ticketing-admin.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Getyourguide_Ticketing_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Getyourguide_Ticketing_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/getyourguide-ticketing-admin.js', array('jquery'), $this->version, false);
	}

	public function adminMain()
	{
		include 'partials/getyourguide-ticketing-admin-display.php';
	}

	public function linkBuilder()
	{
		include 'partials/getyourguide-ticketing-link-builder.php';
	}

	public function register_menu()
	{
		add_menu_page(
			'General Settings',
			'GYG Ticketing',
			'manage_options',
			'getyourguide-ticketing-settings',
			[&$this, 'adminMain'],
			'dashicons-tickets-alt'
		);

		add_submenu_page('getyourguide-ticketing-settings', 'Settings', 'Settings', 'manage_options', 'getyourguide-ticketing-settings');
		add_submenu_page('getyourguide-ticketing-settings', 'Link Builder', 'Link Builder', 'manage_options', 'getyourguide-ticketing-link', [&$this, 'linkBuilder']);
	}

	public function init_settings_page()
	{
		register_setting('gygTicketing', 'getyourguide_ticketing_settings');
		add_settings_section(
			'getyourguide_ticketing_section',
			__('GetYourGuide Ticketing Configuration', 'wordpress'),
			null,
			'gygTicketing'
		);

		add_settings_field(
			'getyourguide_ticketing_partner_hash',
			__('Affiliate partner ID', 'wordpress'),
			array($this, 'getyourguide_ticketing_partner_hash_render'),
			'gygTicketing',
			'getyourguide_ticketing_section'
		);

		add_settings_field(
			'getyourguide_ticketing_currency',
			__('Currency', 'wordpress'),
			array($this, 'getyourguide_ticketing_partner_currency'),
			'gygTicketing',
			'getyourguide_ticketing_section'
		);
	}

	function getyourguide_ticketing_partner_hash_render()
	{
		$options = get_option('getyourguide_ticketing_settings');
		$partner_hash = $options['getyourguide_ticketing_partner_hash'];
		include 'partials/fields/partner-hash.php';
	}

	function getyourguide_ticketing_partner_currency()
	{
		$options = get_option('getyourguide_ticketing_settings');
		include 'partials/fields/currency.php';
	}
}
