(function ($) {
  "use strict";

  function getActivitiesIDsFromLink(gygLink) {
    var ids = gygLink.match(/t\d+/g);
    if (ids && ids.length) {
      return ids[0].replace("t", "");
    }
  }

  function formDataToObject(form) {
    var unindexed_array = form.serializeArray();
    var data = {};

    $.map(unindexed_array, function (n, i) {
      data[n["name"]] = n["value"];
    });

    return data;
  }

  function getActivitiesIDs(links) {
    if (links) {
      return links
        .split(String.fromCharCode(10))
        .filter((l) => l.trim() !== "")
        .map(getActivitiesIDsFromLink);
    }

    return [];
  }

  function escapeHtml(unsafe) {
    return unsafe
      .replaceAll("&", "&amp;")
      .replaceAll("<", "&lt;")
      .replaceAll(">", "&gt;")
      .replaceAll('"', "&quot;")
      .replaceAll("'", "&#039;");
  }

  function getParameters(partner_hash, activitiesIDs) {
    return `?partner_id=${escapeHtml(
      partner_hash
    )}&partner_ticketing_activity_ids=${activitiesIDs.join(",")}`;
  }

  function htmlTemplate(link) {
    return `[<a target="_blank" href="${link}">Preview</a>] ${link}`;
  }

  function htmlTemplateDeeplink(data, activitiesIDs) {
    var deeplink = getDeeplink(data.base_url, data.partner_hash, activitiesIDs);

    return htmlTemplate(deeplink);
  }

  function getDeeplink(base_url, partner_hash, activitiesIDs) {
    return `${base_url}${getParameters(partner_hash, activitiesIDs)}`;
  }

  $(window).load(function () {
    var form = $("#ticketing-link-builder-settings");
    form.submit(function (event) {
      event.preventDefault();
      var data = formDataToObject(form);
      var activitiesIDs = [...new Set(getActivitiesIDs(data.links))];

      $("#results").show();

      $("#result-ticketing-c2a-individual").html(
        activitiesIDs
          .map((activityID) => htmlTemplateDeeplink(data, [activityID]))
          .join("<br />")
      );
      $("#result-ticketing-c2a-combined").html(
        htmlTemplateDeeplink(data, activitiesIDs)
      );
    });
  });
})(jQuery);
