<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ticketing.getyourguide.com
 * @since      1.0.0
 *
 * @package    Getyourguide_Ticketing
 * @subpackage Getyourguide_Ticketing/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Getyourguide_Ticketing
 * @subpackage Getyourguide_Ticketing/public
 * @author     Marcello Romanelli <marcello.romanelli@getyourguide.com>
 */
class Getyourguide_Ticketing_Public
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Getyourguide_Ticketing_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Getyourguide_Ticketing_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/getyourguide-ticketing-public.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{
		global $ARB_ATTRIB_PREFIX;

		wp_enqueue_script('ticketing_v1', 'https://cdn.getyourguide.com/partner-ticketing/latest/ticketing.umd.min.js', [], null, true);
		// wp_script_add_data('ticketing_v1',  $ARB_ATTRIB_PREFIX . 'data-gyg-partner-hash', 'ALS1SM0');
		// wp_script_add_data('ticketing_v1',  $ARB_ATTRIB_PREFIX . 'data-gyg-currency', 'USD');
		add_filter('script_loader_tag', 'add_data_attribute', 10, 2);

		function add_data_attribute($tag, $handle)
		{
			$options = get_option('getyourguide_ticketing_settings');

			$partner_hash = $options['getyourguide_ticketing_partner_hash'];
			$partner_currency = $options['getyourguide_ticketing_currency'];
			if ('ticketing_v1' !== $handle)
				return $tag;

			return str_replace(' src', " data-gyg-partner-hash='$partner_hash' data-gyg-currency='$partner_currency' src", $tag);
		}
	}
}
